pub struct TaskContext<S>where
S: TaskStore,{ /* private fields */ }Implementations
Sourceimpl<S> TaskContext<S>
impl<S> TaskContext<S>
Sourcepub fn new(store: S) -> Self
pub fn new(store: S) -> Self
Creates a new TaskContext with the provided store.
Examples found in repository?
examples/basic.rs (line 18)
12async fn main() {
13 tracing_subscriber::fmt()
14 .with_max_level(tracing::Level::INFO)
15 .init();
16
17 let task_store = InMemoryTaskStore::new();
18 let context = TaskContext::new(task_store)
19 .register::<MyTask1>()
20 .register::<MyTask2>()
21 .start();
22
23 context
24 .add_task(MyTask1::new("name1".to_string(), 32))
25 .await
26 .unwrap();
27
28 context
29 .add_task(MyTask2::new("name2".to_string(), 39))
30 .await
31 .unwrap();
32
33 tokio::time::sleep(Duration::from_secs(100000000)).await;
34}More examples
examples/nativedb.rs (line 22)
15async fn main() {
16 tracing_subscriber::fmt()
17 .with_max_level(tracing::Level::INFO)
18 .init();
19
20 let task_store = NativeDbTaskStore::default();
21 task_store.restore_tasks().await.unwrap();
22 let context = TaskContext::new(task_store)
23 .register::<MyTask1>()
24 .register::<MyTask2>()
25 .set_concurrency("default", 10)
26 .start();
27
28 context
29 .add_task(MyTask1::new("name1".to_string(), 32))
30 .await
31 .unwrap();
32
33 context
34 .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900))
35 .await
36 .unwrap();
37
38 tokio::time::sleep(Duration::from_secs(100000000)).await;
39}Sourcepub fn register<T>(self) -> Selfwhere
T: Task,
pub fn register<T>(self) -> Selfwhere
T: Task,
Registers a new task type in the context.
Examples found in repository?
examples/basic.rs (line 19)
12async fn main() {
13 tracing_subscriber::fmt()
14 .with_max_level(tracing::Level::INFO)
15 .init();
16
17 let task_store = InMemoryTaskStore::new();
18 let context = TaskContext::new(task_store)
19 .register::<MyTask1>()
20 .register::<MyTask2>()
21 .start();
22
23 context
24 .add_task(MyTask1::new("name1".to_string(), 32))
25 .await
26 .unwrap();
27
28 context
29 .add_task(MyTask2::new("name2".to_string(), 39))
30 .await
31 .unwrap();
32
33 tokio::time::sleep(Duration::from_secs(100000000)).await;
34}More examples
examples/nativedb.rs (line 23)
15async fn main() {
16 tracing_subscriber::fmt()
17 .with_max_level(tracing::Level::INFO)
18 .init();
19
20 let task_store = NativeDbTaskStore::default();
21 task_store.restore_tasks().await.unwrap();
22 let context = TaskContext::new(task_store)
23 .register::<MyTask1>()
24 .register::<MyTask2>()
25 .set_concurrency("default", 10)
26 .start();
27
28 context
29 .add_task(MyTask1::new("name1".to_string(), 32))
30 .await
31 .unwrap();
32
33 context
34 .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900))
35 .await
36 .unwrap();
37
38 tokio::time::sleep(Duration::from_secs(100000000)).await;
39}Sourcepub fn set_concurrency(self, queue: &str, count: u32) -> Self
pub fn set_concurrency(self, queue: &str, count: u32) -> Self
Sets the concurrency level for a specified queue.
Examples found in repository?
examples/nativedb.rs (line 25)
15async fn main() {
16 tracing_subscriber::fmt()
17 .with_max_level(tracing::Level::INFO)
18 .init();
19
20 let task_store = NativeDbTaskStore::default();
21 task_store.restore_tasks().await.unwrap();
22 let context = TaskContext::new(task_store)
23 .register::<MyTask1>()
24 .register::<MyTask2>()
25 .set_concurrency("default", 10)
26 .start();
27
28 context
29 .add_task(MyTask1::new("name1".to_string(), 32))
30 .await
31 .unwrap();
32
33 context
34 .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900))
35 .await
36 .unwrap();
37
38 tokio::time::sleep(Duration::from_secs(100000000)).await;
39}Sourcepub fn start_signal_listener(&self)
pub fn start_signal_listener(&self)
Starts a signal listener to handle shutdown signals.
Sourcepub fn start(self) -> Self
pub fn start(self) -> Self
Starts the task context, including workers and the task cleaner.
Examples found in repository?
examples/basic.rs (line 21)
12async fn main() {
13 tracing_subscriber::fmt()
14 .with_max_level(tracing::Level::INFO)
15 .init();
16
17 let task_store = InMemoryTaskStore::new();
18 let context = TaskContext::new(task_store)
19 .register::<MyTask1>()
20 .register::<MyTask2>()
21 .start();
22
23 context
24 .add_task(MyTask1::new("name1".to_string(), 32))
25 .await
26 .unwrap();
27
28 context
29 .add_task(MyTask2::new("name2".to_string(), 39))
30 .await
31 .unwrap();
32
33 tokio::time::sleep(Duration::from_secs(100000000)).await;
34}More examples
examples/nativedb.rs (line 26)
15async fn main() {
16 tracing_subscriber::fmt()
17 .with_max_level(tracing::Level::INFO)
18 .init();
19
20 let task_store = NativeDbTaskStore::default();
21 task_store.restore_tasks().await.unwrap();
22 let context = TaskContext::new(task_store)
23 .register::<MyTask1>()
24 .register::<MyTask2>()
25 .set_concurrency("default", 10)
26 .start();
27
28 context
29 .add_task(MyTask1::new("name1".to_string(), 32))
30 .await
31 .unwrap();
32
33 context
34 .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900))
35 .await
36 .unwrap();
37
38 tokio::time::sleep(Duration::from_secs(100000000)).await;
39}Sourcepub async fn add_task<T>(&self, task: T) -> Result<(), String>
pub async fn add_task<T>(&self, task: T) -> Result<(), String>
Adds a new task to the context for execution.
Examples found in repository?
examples/basic.rs (line 24)
12async fn main() {
13 tracing_subscriber::fmt()
14 .with_max_level(tracing::Level::INFO)
15 .init();
16
17 let task_store = InMemoryTaskStore::new();
18 let context = TaskContext::new(task_store)
19 .register::<MyTask1>()
20 .register::<MyTask2>()
21 .start();
22
23 context
24 .add_task(MyTask1::new("name1".to_string(), 32))
25 .await
26 .unwrap();
27
28 context
29 .add_task(MyTask2::new("name2".to_string(), 39))
30 .await
31 .unwrap();
32
33 tokio::time::sleep(Duration::from_secs(100000000)).await;
34}More examples
examples/nativedb.rs (line 29)
15async fn main() {
16 tracing_subscriber::fmt()
17 .with_max_level(tracing::Level::INFO)
18 .init();
19
20 let task_store = NativeDbTaskStore::default();
21 task_store.restore_tasks().await.unwrap();
22 let context = TaskContext::new(task_store)
23 .register::<MyTask1>()
24 .register::<MyTask2>()
25 .set_concurrency("default", 10)
26 .start();
27
28 context
29 .add_task(MyTask1::new("name1".to_string(), 32))
30 .await
31 .unwrap();
32
33 context
34 .add_task(MyTask2::new("namexxxxxxx".to_string(), 3900))
35 .await
36 .unwrap();
37
38 tokio::time::sleep(Duration::from_secs(100000000)).await;
39}Auto Trait Implementations
impl<S> Freeze for TaskContext<S>
impl<S> !RefUnwindSafe for TaskContext<S>
impl<S> Send for TaskContext<S>where
S: Sync,
impl<S> Sync for TaskContext<S>where
S: Sync,
impl<S> Unpin for TaskContext<S>
impl<S> !UnwindSafe for TaskContext<S>